OSDN Git Service

* see.c, tree-flow-inline.h, tree-phinodes.c: Fix comment
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Mon, 8 May 2006 05:17:54 +0000 (05:17 +0000)
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Mon, 8 May 2006 05:17:54 +0000 (05:17 +0000)
typos.

git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@113621 138bc75d-0d04-0410-961f-82ee72b054a4

gcc/ChangeLog
gcc/see.c
gcc/tree-flow-inline.h
gcc/tree-phinodes.c

index 3acb58b..1bb7acb 100644 (file)
@@ -2,6 +2,9 @@
 
        * config/arm/constraints.md (c): Fix a typo.
 
+       * see.c, tree-flow-inline.h, tree-phinodes.c: Fix comment
+       typos.
+
 2006-05-07  H.J. Lu  <hongjiu.lu@intel.com>
 
        PR target/24879
index 603d72e..8e4bd29 100644 (file)
--- a/gcc/see.c
+++ b/gcc/see.c
@@ -567,7 +567,7 @@ struct see_register_properties
 };
 
 /* Occurrence of an expression.
-   There must be at most one available occurance and at most one anticipatable
+   There must be at most one available occurrence and at most one anticipatable
    occurrence per basic block.  */
 struct see_occr
 {
@@ -925,7 +925,7 @@ hash_del_properties (void *p)
    set ((reg:WIDEmode r1) (sign_extend:WIDEmode (reg:NARROWmode r2)))
 
    The value of the key is (REGNO (reg:WIDEmode r1))
-   It is posibble to search this hash in two ways:
+   It is possible to search this hash in two ways:
    1.  By a register rtx. The Value that is been compared to the keys is the
        REGNO of it.
    2.  By an insn with the above pattern. The Value that is been compared to
@@ -1648,7 +1648,7 @@ see_commit_ref_changes (splay_tree_node stn,
    redundant.
 
    INDEX_MAP is a mapping of an index to an expression.
-   Return true if an instruction was insertedon an edge.
+   Return true if an instruction was inserted on an edge.
    Otherwise, return false.  */
 
 static bool
@@ -2424,7 +2424,7 @@ see_replace_src (rtx *x, void *data)
    set (subreg (dest_extension_reg)) (rhs)
 
    We do this in 4 steps:
-   a. Replace every use of dest_reg with a new preudo register.
+   a. Replace every use of dest_reg with a new pseudo register.
    b. Replace every instance of dest_reg with the subreg.
    c. Replace every use of the new pseudo register back to dest_reg.
    d. Try to recognize and simplify.
@@ -2476,7 +2476,7 @@ see_def_extension_not_merged (struct see_ref_s *curr_ref_s, rtx def_se)
   subreg = gen_lowpart_SUBREG (dest_mode, dest_extension_reg);
   new_pseudo_reg = gen_reg_rtx (source_extension_mode);
 
/* Step a: Replace every use of dest_real_reg with a new preudo register.  */
   d.from = dest_real_reg;
   d.to = new_pseudo_reg;
   note_uses (&PATTERN (ref_copy), see_replace_src, &d);
index 98cb512..5f7efa7 100644 (file)
@@ -1390,8 +1390,8 @@ first_imm_use_stmt (imm_use_iterator *imm, tree var)
   imm->next_imm_name = NULL_USE_OPERAND_P;
 
   /* iter_node is used as a marker within the immediate use list to indicate
-     where the end of the current stmt's uses are.  Iintialize it to NULL
-     stmt and use, which indicateds a marker node.  */
+     where the end of the current stmt's uses are.  Initialize it to NULL
+     stmt and use, which indicates a marker node.  */
   imm->iter_node.prev = NULL_USE_OPERAND_P;
   imm->iter_node.next = NULL_USE_OPERAND_P;
   imm->iter_node.stmt = NULL_TREE;
index 5e85aea..98b011f 100644 (file)
@@ -417,7 +417,7 @@ remove_phi_arg_num (tree phi, int i)
       use_operand_p old_p, new_p;
       old_p = &PHI_ARG_IMM_USE_NODE (phi, num_elem - 1);
       new_p = &PHI_ARG_IMM_USE_NODE (phi, i);
-      /* Set use on new node, and link into last elements's place.  */
+      /* Set use on new node, and link into last element's place.  */
       *(new_p->use) = *(old_p->use);
       relink_imm_use (new_p, old_p);
     }
@@ -2476,7 +2476,7 @@ see_def_extension_not_merged (struct see_ref_s *curr_ref_s, rtx def_se)
   new_pseudo_reg = gen_reg_rtx (source_extension_mode);
 
-  /* Step a: Replace every use of dest_real_reg with a new preudo register.  */
+  /* Step a: Replace every use of dest_real_reg with a new pseudo register.  */
   d.from = dest_real_reg;
   d.to = new_pseudo_reg;